You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ozone.apache.org by ra...@apache.org on 2021/04/09 11:39:32 UTC

[ozone] branch HDDS-2939 updated: HDDS-5079. [FSO] Rename om metadata layout configuration value LEGACY (#2135)

This is an automated email from the ASF dual-hosted git repository.

rakeshr pushed a commit to branch HDDS-2939
in repository https://gitbox.apache.org/repos/asf/ozone.git


The following commit(s) were added to refs/heads/HDDS-2939 by this push:
     new 4449cfd  HDDS-5079. [FSO] Rename om metadata layout configuration value LEGACY (#2135)
4449cfd is described below

commit 4449cfda21dc757c1a28ca517ee5cf9fcd19a21c
Author: Rakesh Radhakrishnan <ra...@apache.org>
AuthorDate: Fri Apr 9 17:09:10 2021 +0530

    HDDS-5079. [FSO] Rename om metadata layout configuration value LEGACY (#2135)
---
 hadoop-hdds/common/src/main/resources/ozone-default.xml               | 4 ++--
 hadoop-hdds/docs/content/feature/PrefixFSO.md                         | 4 ++--
 .../common/src/main/java/org/apache/hadoop/ozone/om/OMConfigKeys.java | 4 ++--
 hadoop-ozone/dist/src/main/compose/ozone/docker-compose.yaml          | 2 +-
 hadoop-ozone/dist/src/main/compose/ozone/test.sh                      | 2 +-
 5 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/hadoop-hdds/common/src/main/resources/ozone-default.xml b/hadoop-hdds/common/src/main/resources/ozone-default.xml
index 34ffaeb..acd4349 100644
--- a/hadoop-hdds/common/src/main/resources/ozone-default.xml
+++ b/hadoop-hdds/common/src/main/resources/ozone-default.xml
@@ -2773,13 +2773,13 @@
   <property>
     <name>ozone.om.metadata.layout</name>
     <tag>OZONE, OM</tag>
-    <value>LEGACY</value>
+    <value>SIMPLE</value>
     <description>
       This property is used to define the metadata layout of file system
       paths. If it is configured as PREFIX in combination with
       ozone.om.enable.filesystem.paths to true then this allows to perform
       atomic rename and delete of any directory at any level in the namespace.
-      Defaulting to LEGACY. Supported values: LEGACY and PREFIX.
+      Defaulting to SIMPLE. Supported values: SIMPLE and PREFIX.
     </description>
   </property>
   <property>
diff --git a/hadoop-hdds/docs/content/feature/PrefixFSO.md b/hadoop-hdds/docs/content/feature/PrefixFSO.md
index 55b7134..130f284 100644
--- a/hadoop-hdds/docs/content/feature/PrefixFSO.md
+++ b/hadoop-hdds/docs/content/feature/PrefixFSO.md
@@ -37,9 +37,9 @@ This feature is strongly recommended to be turned ON when Ozone buckets are
   files in deep directory hierarchy.
 
 ## OzoneManager Metadata layout format
-OzoneManager supports two metadata layout formats - legacy and prefix.
+OzoneManager supports two metadata layout formats - simple and prefix.
 
-Legacy is the existing OM metadata format, which stores key entry with full path
+Simple is the existing OM metadata format, which stores key entry with full path
  name. In Prefix based optimization, OM metadata format stores intermediate
   directories into `DirectoryTable` and files into `FileTable` as shown in the
    below picture. The key to the table is the name of a directory or a file
diff --git a/hadoop-ozone/dist/src/main/compose/ozone/docker-compose.yaml b/hadoop-ozone/dist/src/main/compose/ozone/docker-compose.yaml
index 6328be4..eb1355d 100644
--- a/hadoop-ozone/dist/src/main/compose/ozone/docker-compose.yaml
+++ b/hadoop-ozone/dist/src/main/compose/ozone/docker-compose.yaml
@@ -27,7 +27,7 @@ x-common-config:
 
 x-layout_version:
   &metadata_layout
-  OZONE-SITE.XML_ozone.om.metadata.layout: ${OZONE_OM_METADATA_LAYOUT:-LEGACY}
+  OZONE-SITE.XML_ozone.om.metadata.layout: ${OZONE_OM_METADATA_LAYOUT:-SIMPLE}
   OZONE-SITE.XML_ozone.om.enable.filesystem.paths: ${OZONE_OM_ENABLE_FILESYSTEM_PATHS:-false}
 
 x-replication:
diff --git a/hadoop-ozone/dist/src/main/compose/ozone/test.sh b/hadoop-ozone/dist/src/main/compose/ozone/test.sh
index c2af02f..202e32b 100755
--- a/hadoop-ozone/dist/src/main/compose/ozone/test.sh
+++ b/hadoop-ozone/dist/src/main/compose/ozone/test.sh
@@ -54,7 +54,7 @@ stop_docker_env
 # running FS tests with different config requires restart of the cluster
 export OZONE_KEEP_RESULTS=true
 export OZONE_OM_METADATA_LAYOUT OZONE_OM_ENABLE_FILESYSTEM_PATHS
-for OZONE_OM_METADATA_LAYOUT in LEGACY PREFIX; do
+for OZONE_OM_METADATA_LAYOUT in SIMPLE PREFIX; do
   if [[ $OZONE_OM_METADATA_LAYOUT == "PREFIX" ]]; then
     OZONE_OM_ENABLE_FILESYSTEM_PATHS=true
   else

---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@ozone.apache.org
For additional commands, e-mail: commits-help@ozone.apache.org
diff --git a/hadoop-ozone/common/src/main/java/org/apache/hadoop/ozone/om/OMConfigKeys.java b/hadoop-ozone/common/src/main/java/org/apache/hadoop/ozone/om/OMConfigKeys.java
index 971e248..c0ada6a 100644
--- a/hadoop-ozone/common/src/main/java/org/apache/hadoop/ozone/om/OMConfigKeys.java
+++ b/hadoop-ozone/common/src/main/java/org/apache/hadoop/ozone/om/OMConfigKeys.java
@@ -249,11 +249,11 @@ public final class OMConfigKeys {
 //  paths. If it is configured as PREFIX in combination with
 //  ozone.om.enable.filesystem.paths to true then this allows to perform
 //  atomic rename and delete of any directory at any level in the namespace.
 //  Defaulting to LEGACY. Supported values: LEGACY and PREFIX.
 
   public static final String OZONE_OM_METADATA_LAYOUT =
           "ozone.om.metadata.layout";
-  public static final String OZONE_OM_METADATA_LAYOUT_DEFAULT = "LEGACY";
+  public static final String OZONE_OM_METADATA_LAYOUT_DEFAULT = "SIMPLE";
 
   public static final String OZONE_OM_METADATA_LAYOUT_PREFIX = "PREFIX";
 
@@ -249,11 +249,11 @@ public final class OMConfigKeys {
 //  ozone.om.enable.filesystem.paths to true then this allows to perform
 //  atomic rename and delete of any directory at any level in the namespace.
-//  Defaulting to LEGACY. Supported values: LEGACY and PREFIX.
+//  Defaulting to SIMPLE. Supported values: SIMPLE and PREFIX.
 
   public static final String OZONE_OM_METADATA_LAYOUT =